@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect musical modal functions
 
-our $VERSION = '0.0314';
+our $VERSION = '0.0315';
 
 use Moo;
 use strictures 2;
@@ -108,7 +108,7 @@ sub _build__database {
 
     # build a prolog fact for each base note
     for my $base (@chromatic) {
-        my ($mode_base) = map { lc } MIDI::Util::midi_format($base);
+        my ($mode_base) = map { lc } midi_format($base);
 
         # consider each mode's properties
         for my $mode (sort keys %{ $self->_modes }) {
@@ -122,7 +122,7 @@ sub _build__database {
             for my $note (@notes) {
                 my $n = Music::Note->new($note, 'isobase');
                 $n->en_eq('flat') if $note =~ /#/;
-                push @pitches, map { lc } MIDI::Util::midi_format($n->format('isobase'));
+                push @pitches, map { lc } midi_format($n->format('isobase'));
             }
 
             my $i = 0; # increment for each of 7 diatonic modes
@@ -241,7 +241,7 @@ Music::ModalFunction - Inspect musical modal functions
 
 =head1 VERSION
 
-version 0.0314
+version 0.0315
 
 =head1 SYNOPSIS
 
